@@ -653,40 +653,6 @@ class AsyncFuncWrapper(base.FuncWrapper):
                 Utils.log.error(err)
 
 
-class FuncCache:
-    """函数缓存
-
-    使用堆栈缓存实现的函数缓存，在有效期内函数签名一致就会命中缓存
-
-    """
-
-    def __init__(self, maxsize=0xff, ttl=10):
-
-        self._cache = StackCache(maxsize, ttl)
-
-    def __call__(self, func):
-
-        @base.Utils.func_wraps(func)
-        async def _wrapper(*args, **kwargs):
-
-            func_sign = Utils.params_sign(func, *args, **kwargs)
-
-            result = self._cache.get(func_sign)
-
-            if result is None:
-
-                result = await Utils.awaitable_wrapper(
-                    func(*args, **kwargs)
-                )
-
-                if result is not None:
-                    self._cache.set(func_sign, result)
-
-            return result
-
-        return _wrapper
-
-
 class ShareFuture:
     """共享Future装饰器
 
@@ -703,41 +669,48 @@ class ShareFuture:
         @base.Utils.func_wraps(func)
         async def _wrapper(*args, **kwargs):
 
-            future = None
+            nonlocal self, func
 
-            func_sign = Utils.params_sign(func, *args, **kwargs)
-
-            if func_sign in self._future:
-
-                future = asyncio.Future()
-
-                self._future[func_sign].append(future)
-
-            else:
-
-                future = Utils.create_task(
-                    func(*args, **kwargs)
-                )
-
-                if future is None:
-                    TypeError(r'Not Coroutine Object')
-
-                self._future[func_sign] = [future]
-
-                future.add_done_callback(
-                    Utils.func_partial(self._clear_future, func_sign)
-                )
-
-            return await future
+            return await self._make_future(
+                Utils.params_sign(func, *args, **kwargs),
+                func, *args, **kwargs
+            )
 
         return _wrapper
 
-    def _clear_future(self, func_sign, _):
+    def _make_future(self, _func_sign, func, *args, **kwargs):
 
-        if func_sign not in self._future:
+        future = None
+
+        if _func_sign in self._future:
+
+            future = asyncio.Future()
+
+            self._future[_func_sign].append(future)
+
+        else:
+
+            future = Utils.create_task(
+                func(*args, **kwargs)
+            )
+
+            if future is None:
+                TypeError(r'Not Coroutine Object')
+
+            self._future[_func_sign] = [future]
+
+            future.add_done_callback(
+                Utils.func_partial(self._clear_future, _func_sign)
+            )
+
+        return future
+
+    def _clear_future(self, _func_sign, _):
+
+        if _func_sign not in self._future:
             return
 
-        futures = self._future.pop(func_sign)
+        futures = self._future.pop(_func_sign)
 
         result = futures.pop(0).result()
 
@@ -745,15 +718,58 @@ class ShareFuture:
             future.set_result(Utils.deepcopy(result))
 
 
+class FuncCache(ShareFuture):
+    """函数缓存
+
+    使用堆栈缓存实现的函数缓存，在有效期内函数签名一致就会命中缓存
+
+    """
+
+    def __init__(self, maxsize=0xffff, ttl=10):
+
+        super().__init__()
+
+        self._cache = StackCache(maxsize, ttl)
+
+    def __call__(self, func):
+
+        @base.Utils.func_wraps(func)
+        async def _wrapper(*args, **kwargs):
+
+            nonlocal self, func
+
+            _func_sign = Utils.params_sign(func, *args, **kwargs)
+
+            return await self._make_future(
+                _func_sign,
+                self._do_func_with_cache, _func_sign, func, *args, **kwargs
+            )
+
+        return _wrapper
+
+    async def _do_func_with_cache(self, _func_sign, func, *args, **kwargs):
+
+        result = self._cache.get(_func_sign)
+
+        if result is None:
+
+            result = await func(*args, **kwargs)
+
+            if result is not None:
+                self._cache.set(_func_sign, result)
+
+        return result
+
+
 class TimeDiff:
 
     def __init__(self):
 
-        self._start_time = self._last_check_time = Utils.loop_time()
+        self._start_time = self._last_check_time = Utils.timestamp(True)
 
     def check(self):
 
-        now_time = Utils.loop_time()
+        now_time = Utils.timestamp(True)
 
         diff_time_1 = now_time - self._start_time
         diff_time_2 = now_time - self._last_check_time
