@@ -20,28 +20,22 @@ class RedisDelegate:
     """Redis功能组件
     """
 
-    def __init__(
-            self, host, port, password, max_connections,
-            db_base=0, default_expire=3600, key_prefix=r'', pool_name=None,
-            **kwargs
-    ):
+    def __init__(self, name=None):
 
-        self._redis_pool = RedisClient(
-            host=host, port=port, password=password, max_connections=max_connections,
-            db_base=db_base, default_expire=default_expire, key_prefix=key_prefix,
-            **kwargs
-        )
+        self._redis_pool = None
 
-        self._pool_name = pool_name if pool_name is not None else Utils.uuid1()[:8]
+        self._name = name if name is not None else Utils.uuid1()[:8]
 
-        self._redis_client_context = WeakContextVar(f'redis_client_{self._pool_name}')
+        self._redis_client_context = WeakContextVar(f'redis_client_{self._name}')
 
     @property
     def redis_pool(self):
 
         return self._redis_pool
 
-    async def async_init_redis(self):
+    async def async_init_redis(self, *args, **kwargs):
+
+        self._redis_pool = RedisClient(*args, **kwargs)
 
         await self._redis_pool.initialize()
 
@@ -57,8 +51,6 @@ class RedisDelegate:
 
         async with self.get_cache_client() as cache:
             result = bool(await cache.time())
-            await cache.set(r'test', [1, 2, 3, 4])
-            print(await cache.get(r'test'))
 
         return result
 
