@@ -120,7 +120,11 @@ class MongoDelegate:
     """Mongo功能组件
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self):
+
+        self._mongo_pool = None
+
+    async def async_init_mongo(self, *args, **kwargs):
 
         self._mongo_pool = MongoPool(*args, **kwargs)
 
