@@ -1,16 +1,37 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
+import ctypes
 import asyncio
 
+from threading import Thread as _Thread
 from concurrent.futures import ThreadPoolExecutor
-from multiprocessing import Lock, Manager
-from contextlib import contextmanager
 
 from hagworm.extend.interface import RunnableInterface, TaskInterface
 
 from .base import Utils
 
 
+class Thread(_Thread):
+    """带强制停止功能的线程，如非必要请勿使用
+    """
+
+    def stop(self):
+
+        if ctypes.pythonapi.PyThreadState_SetAsyncExc(
+            ctypes.c_long(self.ident), ctypes.py_object(SystemExit)
+        ) > 1:
+            raise SystemError(r'Kill Thread Failed')
+
+    def wait(self, timeout):
+
+        self.join(timeout)
+
+        if self.is_alive():
+            self.stop()
+
+
 class ThreadPool(RunnableInterface):
     """线程池，桥接线程与协程
     """
