@@ -48,6 +48,7 @@ from stdnum import luhn
 from dateutil.parser import parse as date_parse
 
 from .error import BaseError
+from .text import StrUtils
 
 
 class Utils:
@@ -63,8 +64,6 @@ class Utils:
 
     _FALSE_VALUES = {r'null', r'none', r'nil', r'false', r'0', r'', False, 0}
 
-    SAFE_STRING_BASE = r'2346789BCEFGHJKMPQRTVWXY'
-
     math = math
     random = random
     textwrap = textwrap
@@ -102,6 +101,11 @@ class Utils:
 
         warnings.warn(val, DeprecationWarning)
 
+    @classmethod
+    def get_node_id(cls):
+
+        return cls.md5(f'{cls.getpid()}@{uuid.getnode()}')
+
     @classmethod
     def utf8(cls, val):
 
@@ -494,14 +498,14 @@ class Utils:
     @classmethod
     def radix24(cls, val, align=0):
 
-        base = cls.SAFE_STRING_BASE
+        base = StrUtils.SAFE_STRING_BASE
 
         return cls.radix_n(val, base, 24, align)
 
     @classmethod
     def radix24_to_10(cls, val):
 
-        base = cls.SAFE_STRING_BASE
+        base = StrUtils.SAFE_STRING_BASE
 
         return cls.radix_n_to_10(val, base, 24)
 
