@@ -43,6 +43,7 @@ class _Response:
         self._send = None
 
         self._request_id = Utils.uuid1_urn()
+        self._request_time = Utils.timestamp(True)
 
         REQUEST_ID_CONTEXT.set(self._request_id)
 
@@ -56,6 +57,7 @@ class _Response:
 
         message.setdefault(r'headers', [])
 
+        message[r'headers'].append((b'x-delayed', str(Utils.timestamp(True) - self._request_time).encode(r'latin-1')))
         message[r'headers'].append((b'x-timestamp', str(Utils.timestamp(True)).encode(r'latin-1')))
         message[r'headers'].append((b'x-request-id', self._request_id.encode(r'latin-1')))
 
